import { Col } from "zol";


/**
 * Number of characters in string
 *
 * SQL equivalent: char_length, length
 */
export declare function charLength<s>(str: Col<s, string>): Col<s, number>;

/**
 * Convert string to lower case
 *
 * SQL equivalent: lower
 */
export declare function lower<s>(str: Col<s, string>): Col<s, string>;

/**
 * Convert string to upper case
 *
 * SQL equivalent: upper
 */
export declare function upper<s>(str: Col<s, string>): Col<s, string>;

/**
 * Location of specified substring. The first character in the haystack
 * is 1 (not 0). A result of 0 means that the substring was not found.
 *
 * SQL equivalent: strpos, position
 */
export declare function strpos<s>(haystack: Col<s, string>, needle: Col<s, string>): Col<s, number>;

/**
 * Extract substring. The first character in the string has index 1.
 * Extracts starting from "from" until the end of the string.
 *
 * SQL equivalent: substr, substring
 */
export declare function substr<s>(str: Col<s, string>, from: Col<s, number>): Col<s, string>;

/**
 * Extract substring. The first character in the string has index 1.
 * Extracts starting from "from" for "count" characters.
 *
 * SQL equivalent: substr, substring
 */
export declare function substr<s>(str: Col<s, string>, from: Col<s, number>, count: Col<s, number>): Col<s, string>;

/**
 * Character with the given code. For UTF8 the argument is treated as a
 * Unicode code point. For other multibyte encodings the argument must
 * designate an ASCII character. The NULL (0) character is not allowed
 * because text data types cannot store such bytes.
 *
 * SQL equivalent: chr
 */
export declare function chr<s>(code: Col<s, number>): Col<s, string>;

/**
 * Remove all space characters from the start and end of string.
 *
 * SQL equivalent: btrim
 */
export declare function btrim<s>(str: Col<s, string>): Col<s, string>;

/**
 * Remove the longest string consisting only of characters in characters
 * from the start and end of string.
 *
 * SQL equivalent: btrim
 */
export declare function btrim<s>(str: Col<s, string>, characters: Col<s, string>): Col<s, string>;

/**
 * Remove all space characters from the start of string.
 *
 * SQL equivalent: ltrim
 */
export declare function ltrim<s>(str: Col<s, string>): Col<s, string>;

/**
 * Remove the longest string consisting only of characters in characters
 * from the start of string.
 *
 * SQL equivalent: ltrim
 */
export declare function ltrim<s>(str: Col<s, string>, characters: Col<s, string>): Col<s, string>;

/**
 * Remove all space characters from the end of string.
 *
 * SQL equivalent: rtrim
 */
export declare function rtrim<s>(str: Col<s, string>): Col<s, string>;

/**
 * Remove the longest string consisting only of characters in characters
 * from the end of string.
 *
 * SQL equivalent: rtrim
 */
export declare function rtrim<s>(str: Col<s, string>, characters: Col<s, string>): Col<s, string>;

/**
 * Convert number to its equivalent hexadecimal representation.
 *
 * SQL equivalent: to_hex
 */
export declare function toHex<s>(num: Col<s, number>): Col<s, string>;


