import { SqlType, Unsafe } from 'zol';

/**
 * Number of characters in string
 *
 * SQL equivalent: char_length, length
 */
function charLength(str) {
    return Unsafe.unsafeFun("char_length", str, SqlType.intParser);
}
/**
 * Convert string to lower case
 *
 * SQL equivalent: lower
 */
function lower(str) {
    return Unsafe.unsafeFun("lower", str, SqlType.stringParser);
}
/**
 * Convert string to upper case
 *
 * SQL equivalent: upper
 */
function upper(str) {
    return Unsafe.unsafeFun("upper", str, SqlType.stringParser);
}
/**
 * Location of specified substring. The first character in the haystack
 * is 1 (not 0). A result of 0 means that the substring was not found.
 *
 * SQL equivalent: strpos, position
 */
function strpos(haystack, needle) {
    return Unsafe.unsafeFun2("strpos", haystack, needle, SqlType.intParser);
}
function substr(str, from, count) {
    if (count === undefined) {
        return Unsafe.unsafeFun2("substr", str, from, SqlType.stringParser);
    }
    else {
        return Unsafe.unsafeFun3("substr", str, from, count, SqlType.stringParser);
    }
}
/**
 * Character with the given code. For UTF8 the argument is treated as a
 * Unicode code point. For other multibyte encodings the argument must
 * designate an ASCII character. The NULL (0) character is not allowed
 * because text data types cannot store such bytes.
 *
 * SQL equivalent: chr
 */
function chr(code) {
    return Unsafe.unsafeFun("chr", code, SqlType.stringParser);
}
function btrim(str, characters) {
    if (characters === undefined) {
        return Unsafe.unsafeFun("btrim", str, SqlType.stringParser);
    }
    else {
        return Unsafe.unsafeFun2("btrim", str, characters, SqlType.stringParser);
    }
}
function ltrim(str, characters) {
    if (characters === undefined) {
        return Unsafe.unsafeFun("ltrim", str, SqlType.stringParser);
    }
    else {
        return Unsafe.unsafeFun2("ltrim", str, characters, SqlType.stringParser);
    }
}
function rtrim(str, characters) {
    if (characters === undefined) {
        return Unsafe.unsafeFun("rtrim", str, SqlType.stringParser);
    }
    else {
        return Unsafe.unsafeFun2("rtrim", str, characters, SqlType.stringParser);
    }
}
/**
 * Convert number to its equivalent hexadecimal representation.
 *
 * SQL equivalent: to_hex
 */
function toHex(num) {
    return Unsafe.unsafeFun("to_hex", num, SqlType.stringParser);
}

export { charLength, lower, upper, strpos, substr, chr, btrim, ltrim, rtrim, toHex };
//# sourceMappingURL=zol-string.es5.js.map
