(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('zol')) :
	typeof define === 'function' && define.amd ? define(['exports', 'zol'], factory) :
	(factory((global.zolString = {}),global.zol));
}(this, (function (exports,zol) { 'use strict';

/**
 * Number of characters in string
 *
 * SQL equivalent: char_length, length
 */
function charLength(str) {
    return zol.Unsafe.unsafeFun("char_length", str, zol.SqlType.intParser);
}
/**
 * Convert string to lower case
 *
 * SQL equivalent: lower
 */
function lower(str) {
    return zol.Unsafe.unsafeFun("lower", str, zol.SqlType.stringParser);
}
/**
 * Convert string to upper case
 *
 * SQL equivalent: upper
 */
function upper(str) {
    return zol.Unsafe.unsafeFun("upper", str, zol.SqlType.stringParser);
}
/**
 * Location of specified substring. The first character in the haystack
 * is 1 (not 0). A result of 0 means that the substring was not found.
 *
 * SQL equivalent: strpos, position
 */
function strpos(haystack, needle) {
    return zol.Unsafe.unsafeFun2("strpos", haystack, needle, zol.SqlType.intParser);
}
function substr(str, from, count) {
    if (count === undefined) {
        return zol.Unsafe.unsafeFun2("substr", str, from, zol.SqlType.stringParser);
    }
    else {
        return zol.Unsafe.unsafeFun3("substr", str, from, count, zol.SqlType.stringParser);
    }
}
/**
 * Character with the given code. For UTF8 the argument is treated as a
 * Unicode code point. For other multibyte encodings the argument must
 * designate an ASCII character. The NULL (0) character is not allowed
 * because text data types cannot store such bytes.
 *
 * SQL equivalent: chr
 */
function chr(code) {
    return zol.Unsafe.unsafeFun("chr", code, zol.SqlType.stringParser);
}
function btrim(str, characters) {
    if (characters === undefined) {
        return zol.Unsafe.unsafeFun("btrim", str, zol.SqlType.stringParser);
    }
    else {
        return zol.Unsafe.unsafeFun2("btrim", str, characters, zol.SqlType.stringParser);
    }
}
function ltrim(str, characters) {
    if (characters === undefined) {
        return zol.Unsafe.unsafeFun("ltrim", str, zol.SqlType.stringParser);
    }
    else {
        return zol.Unsafe.unsafeFun2("ltrim", str, characters, zol.SqlType.stringParser);
    }
}
function rtrim(str, characters) {
    if (characters === undefined) {
        return zol.Unsafe.unsafeFun("rtrim", str, zol.SqlType.stringParser);
    }
    else {
        return zol.Unsafe.unsafeFun2("rtrim", str, characters, zol.SqlType.stringParser);
    }
}
/**
 * Convert number to its equivalent hexadecimal representation.
 *
 * SQL equivalent: to_hex
 */
function toHex(num) {
    return zol.Unsafe.unsafeFun("to_hex", num, zol.SqlType.stringParser);
}

exports.charLength = charLength;
exports.lower = lower;
exports.upper = upper;
exports.strpos = strpos;
exports.substr = substr;
exports.chr = chr;
exports.btrim = btrim;
exports.ltrim = ltrim;
exports.rtrim = rtrim;
exports.toHex = toHex;

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=zol-string.umd.js.map
